import { Graph, Cell } from "@antv/x6";
import { BorderSize, TopicType } from "@/enum";
import { addTopic } from "@/pages/mindmap/mindMap";
import { MindMapProjectInfo } from "@/types";

export const bindMindMapEvents = (
  graph: Graph,
  mindProjectInfo?: MindMapProjectInfo,
  setMindProjectInfo?: (info: MindMapProjectInfo) => void,
  setSelectedCell?: (cell: Cell[]) => void
) => {
  // 选中的节点/边发生改变(增删)时触发
  graph.on('selection:changed', ({selected}: {selected: Cell[];}) => {
    setSelectedCell?.(selected);
  })

  // 双击画布空白-新增自由主题
  graph.on("blank:dblclick", (args) => {
    if(setMindProjectInfo) {
      const topic = addTopic(TopicType.branch, setMindProjectInfo, undefined, {
        x: args.x,
        y: args.y,
        setMindProjectInfo,
        type: TopicType.branch,
        label: "自由主题",
        borderSize: BorderSize.medium,
      });

      graph.resetSelection(topic?.id)
    }
  });
};
